import 'dart:collection';

abstract class EventRepository {
  Future<List<List>> getEventsForHabit(int habitId);
  Future<SplayTreeMap<DateTime, List>> getEventsMapForHabit(int habitId);
  Future<void> insertEvent(int habitId, DateTime date, List event);
  Future<void> deleteEvent(int habitId, DateTime date);
  Future<void> deleteAllEventsForHabit(int habitId);
  Future<void> insertEventsForHabit(int habitId, Map<DateTime, List> events);
  Future<void> deleteAllEvents();
}
